@@ -7,11 +7,13 @@
 # nor does it submit to any jurisdiction.
 #
 
-from climetlab.core.plugins import directories
-import os
-import yaml
-from collections import defaultdict
 import logging
+import os
+from collections import defaultdict
+
+import yaml
+
+from climetlab.core.plugins import directories
 from climetlab.utils.html import css
 
 LOG = logging.getLogger(__name__)
@@ -19,6 +21,8 @@ LOG = logging.getLogger(__name__)
 
 YAML_FILES = None
 
+IGNORE = ["magics.yaml", "colours.yaml"]
+
 
 def _guess(data, path):
     if "dataset" in data:
@@ -51,11 +55,14 @@ class Entry:
         self.hidden = data.get("hidden", False)
 
     def _repr_html_(self):
-        html = [css("table")]
-        html.append("<table class='climetlab'>")
-        html.append("<tr><td>Name:</td><td>%s</td></tr>" % self.name)
-        html.append("<tr><td>Collection:</td><td>%s</td></tr>" % self.kind)
-        html.append("<tr><td>Path:</td><td>%s</td></tr>" % self.path)
+        html = [
+            css("table"),
+            "<table class='climetlab'>",
+            "<tr><td>Name:</td><td>%s</td></tr>" % self.name,
+            "<tr><td>Collection:</td><td>%s</td></tr>" % self.kind,
+            "<tr><td>Path:</td><td>%s</td></tr>" % self.path,
+        ]
+
         html.append(
             "<tr><td>Definition:</td><td><pre>%s</pre></td></tr>"
             % (yaml.dump(self.data, default_flow_style=False),)
@@ -70,28 +77,32 @@ def _load_yaml_files():
         return YAML_FILES
 
     YAML_FILES = defaultdict(dict)
-    for root, _, files in os.walk(*directories()):
-        for file in [f for f in files if f.endswith(".yaml")]:
-            path = os.path.join(root, file)
-            try:
-                with open(path) as f:
-                    data = yaml.load(f.read(), Loader=yaml.SafeLoader)
-                    name, _ = os.path.splitext(os.path.basename(path))
-                    kind = _guess(data, path)
-                    collection = YAML_FILES[kind]
-                    if name in collection:
-                        LOG.warning(
-                            "Duplicate entry for %s %s (using %s, ignoring %s)",
-                            kind,
-                            name,
-                            collection[name].path,
-                            path,
-                        )
-                    else:
-                        collection[name] = Entry(name, kind, path, data)
+    for directory in directories():
+        for root, _, files in os.walk(directory):
+            for file in [f for f in files if f.endswith(".yaml")]:
+                if file in IGNORE:
+                    continue
+                path = os.path.join(root, file)
+                try:
+                    with open(path) as f:
+                        data = yaml.load(f.read(), Loader=yaml.SafeLoader)
+                        name, _ = os.path.splitext(os.path.basename(path))
+                        kind = _guess(data, path)
+                        collection = YAML_FILES[kind]
+                        if name in collection:
+                            LOG.warning(
+                                "Duplicate entry for %s %s (using %s, ignoring %s)",
+                                kind,
+                                name,
+                                collection[name].path,
+                                path,
+                            )
+                        else:
+                            collection[name] = Entry(name, kind, path, data)
 
-            except Exception:
-                LOG.error("Cannot process YAML file %s", path, exc_info=True)
+                except Exception:
+                    LOG.error("Cannot process YAML file %s", path, exc_info=True)
+                    raise
 
     return YAML_FILES
 
@@ -99,9 +110,15 @@ def _load_yaml_files():
 def get_data_entry(kind, name):
     files = _load_yaml_files()
     if kind not in files:
-        raise Exception("No collection named '%s'" % (kind,))
+        raise KeyError("No collection named '%s'" % (kind,))
     if name not in files[kind]:
-        raise Exception("No object '%s' in collection named '%s'" % (name, kind,))
+        raise KeyError(
+            "No object '%s' in collection named '%s'"
+            % (
+                name,
+                kind,
+            )
+        )
 
     return files[kind][name]
 
@@ -116,3 +133,8 @@ def data_entries(kind=None):
         for entry in _load_yaml_files().get(kind, {}).values():
             if not entry.hidden:
                 yield entry
+
+
+def clear_cache():
+    global YAML_FILES
+    YAML_FILES = None
