@@ -7,11 +7,15 @@
 # nor does it submit to any jurisdiction.
 #
 
-import os
-import entrypoints
-import climetlab
-from importlib import import_module
 import logging
+import os
+from importlib import import_module
+
+import entrypoints
+
+import climetlab
+
+from .settings import SETTINGS
 
 LOG = logging.getLogger(__name__)
 
@@ -45,10 +49,9 @@ def find_plugin(directory, name, loader):
     for path, _, files in os.walk(directory):
         path = path[n:]
         for f in files:
-            if f.endswith(".yaml"):
-                if f[:-5] == name:
-                    full = os.path.join(directory, path, f)
-                    return loader.load_yaml(full)
+            if f.endswith(".yaml") and f[:-5] == name:
+                full = os.path.join(directory, path, f)
+                return loader.load_yaml(full)
 
             if f.endswith(".py"):
                 p = os.path.join(path, f[:-3])
@@ -61,7 +64,13 @@ def find_plugin(directory, name, loader):
 
 
 def directories():
-    result = [os.path.dirname(climetlab.__file__)]
+
+    result = []
+    for conf in ("styles-directories", "projections-directories", "layers-directories"):
+        for d in SETTINGS.get(conf):
+            if os.path.exists(d) and os.path.isdir(d):
+                result.append(d)
+
     for kind in ("dataset", "source"):
         for _, v in load_plugins(kind).items():
             try:
@@ -69,4 +78,7 @@ def directories():
                 result.append(os.path.dirname(module.__file__))
             except Exception:
                 LOG.error("Cannot load module %s", v.module_name, exc_info=True)
+
+    result.append(os.path.dirname(climetlab.__file__))
+
     return result
