@@ -28,7 +28,10 @@ class MeteonetRadar(Meteonet):
     See https://github.com/meteofrance/meteonet
     """
 
-    def __init__(self, domain="NW", variable="rainfall", year=2016, month=8, part=3):
+    def __init__(self):
+        pass
+
+    def _load(self, domain="NW", variable="rainfall", year=2016, month=8, part=3):
 
         url = "{url}/radar/radar_coords_{domain}.npz".format(
             url=self.URL, domain=domain
