@@ -45,15 +45,21 @@ class XArrayHelper:
         driver.plot_xarray(self.data, self.name, dimension_settings)
 
     def field_metadata(self):
-        return dict(
-            north=self.north,
-            south=self.south,
-            east=self.east,
-            west=self.west,
-            # # TODO:
-            # south_north_increment=None,
-            # west_east_increment=None,
+        shape = self.var.shape
+        result = dict(shape=(shape[-2], shape[-1]))
+        result.update(self.var.attrs)
+        result.update(
+            dict(
+                north=self.north,
+                south=self.south,
+                east=self.east,
+                west=self.west,
+                # # TODO:
+                # south_north_increment=None,
+                # west_east_increment=None,
+            )
         )
+        return result
 
 
 def helper(data, *args, **kwargs):
